<?php
/** 
*
* search_ignore_words [Mexican Spanish]
*
* @package language
* @version $Id$
* @copyright (c) 2007 phpBB Group.
* @author 2013-7-13 - Traducido por cisco007 for phpbbmexico.com.
* @author - ImagePack made by Xoom (webmaster of http://www.muchografico.com and colaborator of http://www.phpbb-es.com) 
* @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU General Public License 
*
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

$words = array(
	'un',
	'acerca',
	'después',
	'hace',
	'todo',
	'casi',
	'largo',
	'montón',
	'también',
	'soy',
	'un',
	'y',
	'respuesta',
	'cualquier',
	'cualquiera',
	'cualesquiera',
	'lugar',
	'son',
	'no son',
	'alrededor',
	'como',
	'preguntar',
	'preguntado',
	'en',
	'mal',
	'ser',
	'porque',
	'sido',
	'antes',
	'siendo',
	'mejor',
	'mejores',
	'entre',
	'grande',
	'por las dudas',
	'pero',
	'por',
	'puede',
	'no puede',
	'venir',
	'podría',
	'no podría',
	'día',
	'dias',
	'hizo',
	'no hizo',
	'hacer',
	'hace',
	'no hace',
	'no',
	'bajo',
	'cada',
	'etc',
	'alterno',
	'sino',
	'aun',
	'nunca',
	'cada',
	'cada uno',
	'cada cual',
	'todos',
	'lejos',
	'encontrar',
	'para',
	'encontrado',
	'de',
	'obtener',
	'ir',
	'yendo',
	'ido',
	'bueno',
	'tener',
	'tenido',
	'tuve',
	'he tenido',
	'tengo',
	'no tengo',
	'teniendo',
	'su',
	'aqui',
	'sus',
	'hogar',
	'cómo',
	'cuándo',
	'href',
	'yo',
	'si',
	'ini',
	'dentro',
	'es',
	'no es',
	'esto',
	'sólo',
	'saber',
	'gran',
	'menos',
	'como',
	'parecido',
	'pequeño',
	'mirando',
	'mirar',
	'mirado',
	'mirando',
	'mucho',
	'talvez',
	'muchos',
	'mi',
	'más',
	'mayor',
	'demasiado',
	'debe',
	'no debe',
	'mío',
	'cerca',
	'necesito',
	'nunca',
	'nuevo',
	'noticias',
	'no',
	'ninguno',
	'nada',
	'ahora',
	'fuera',
	'a menudo',
	'viejo',
	'sobre',
	'una vez',
	'solamente',
	'oops',
	'o',
	'otro',
	'nuestro',
	'nuestros',
	'afuera',
	'sobre',
	'página',
	'por favor',
	'poner',
	'pregunta',
	'preguntas',
	'preguntado',
	'cita',
	'preferir',
	'realmente',
	'reciente',
	'dijo',
	'vió',
	'dicho',
	'ella',
	'ver',
	'debería',
	'sitios',
	'chico',
	'así',
	'algún',
	'algo',
	'a veces',
	'acullá',
	'pronto',
	'tomar',
	'que',
	'verdad',
	'gracias',
	'el',
	'alli',
	'ellos',
	'luego',
	'entonces',
	'esos',
	'estos',
	'aquellos',
	'pienso',
	'travéz',
	'fecha',
	'fechas',
	'para',
	'demasía',
	'bajo',
	'hasta',
	'incierto',
	'arriba',
	'hasta',
	'use',
	'usuarios',
	'versión',
	'muy',
	'vía',
	'querer',
	'fué',
	'camino',
	'nosotros',
	'bien',
	'fueron',
	'fuimos',
	'no fuimos',
	'cuando',
	'dónde',
	'cual',
	'quién',
	'quienes',
	'porque',
	'ancho',
	'con',
	'sin',
	'palabra',
	'malo',
	'peor',
	'podría',
	'escrito',
	'www',
	'yes',
	'ya',
	'tu',
	'tú',
	'tus',
	'AFAIK',
	'IIRC',
	'LOL',
	'ROTF',
	'ROTFLMAO',
	'YMMV',
);

?>